@@ -14,14 +14,8 @@
 #' @export
 print.SVC_mle <- function(x, digits = max(3L, getOption("digits") - 3L), ...) {
 
-  cat(paste0("\nCall:\nSVC_mle with ",
-             ncol(x$data$X),
-             " fixed effect(s) and ",
-             ncol(x$data$W),
-             " SVC(s)\n"))
-  cat(paste0("Using ", nobs(x), " observations at ",
-             nlocs(x), " different locations.\n\n"))
-
+  cat("\nCall:\n", paste(deparse(x$call), sep = "\n", collapse = "\n"), 
+      "\n\n", sep = "")
 
   cat("Coefficients of fixed effects:\n")
   print.default(format(coef(x), digits = digits), print.gap = 2L,
